# Notes

This package provides a selection of components that render form elements for use within a [formsy-react](https://github.com/christianalfoni/formsy-react) form.

By default, the element is wrapped with tags that provide the boilerplate to help include it in a [Bootstrap form](http://getbootstrap.com/css/#forms). This includes a `<label>`, [help text](http://getbootstrap.com/css/#forms-help-text), and some [validation styling](http://getbootstrap.com/css/#forms-control-validation) tied to formsy’s validation state and validation messages.

```
<Input
    type="text"
    name="my-element"
    label="Label"
    help="Some help text to be displayed near the control."
/>
```
[EXAMPLE OUTPUT GOES HERE]

---

## Properties

#### help

`React.PropTypes.string`

#### label

`React.PropTypes.string`

Rendered as label text for the element.

#### layout

`React.PropTypes.oneOf('horizontal', 'vertical', 'elementOnly')` --- default: <code>'horizontal'</code>

Modifies the markup and classes that wrap the form element.

If not 'horizontal' renders as a standard bootstrap form instead.

I've chosen `col-sm-3` for the labels, and `col-sm-9` for the element. It's on the roadmap to make these configurable.

#### validatePristine

`React.PropTypes.bool` --- default: <code>false</code>

Whether to present validation notices on pristine elements.

#### disabled

`React.PropTypes.bool`

Works in conjunction with Formsy.Mixin isFormDisabled.

### Formsy.Mixin properties

* You can pass any [Formsy.Mixin property](https://github.com/christianalfoni/formsy-react/blob/master/API.md#formsymixin).

### Other properties

* Other properties are passed through to the form element, and React will render these according to it’s [HTML attribute whitelist](https://facebook.github.io/react/docs/tags-and-attributes.html). For example a <code>placeholder</code> property passed to the component would be applied to the form control within the component.

---

* [react](https://facebook.github.io/react/)
* [formsy-react](https://github.com/christianalfoni/formsy-react)
* [react-bootstrap](https://github.com/react-bootstrap/react-bootstrap)

https://github.com/IlyaSerdyuk/zend1-bootstrap3

    ## Input elements

    ### Button types

    button
    reset
    submit

    ### Radio / Checkbox

    checkbox
    radio

    ### Texty types

    text
    password
    hidden
    email
    url
    tel
    file
    color
    image
    number
    range
    search

    ### Date / time

    date
    datetime
    datetime-local
    time
    week
    month


<p>
<label>
    Enter a breed: <input type="text" name="breed" list="breeds">
</label>
<datalist id="breeds">
    <label>
        or select one from the list:
        <select name="breed">
            <option value=""> (none selected)
            <option>Abyssinian
            <option>Alpaca
            <!-- ... -->
        </select>
    </label>
</datalist>
</p>

<input type="color" value="#000000" list="colors" />
<datalist id="colors">
  <option>#ff0000</option>
  <option>#0000ff</option>
  <option>#00ff00</option>
  <option>#ffff00</option>
  <option>#00ffff</option>
</datalist>

<h3>Common properties</h3>
<dl>
    <dt>name: <code>React.PropTypes.string</code></dt>
    <dd>See formsy-react docs.</dd>
    <dt>value: <code>mixed type</code></dt>
    <dd>See formsy-react docs.</dd>
    <dt>help: <code>React.PropTypes.string</code></dt>
    <dt>onChange: <code>React.PropTypes.func</code></dt>
    <dd>If supplied, callback signature is (name, value) where <code>name</code> is the name of the element, and <code>value</code> is it's value.</dd>
</dl>
